Interval

Struct Interval 

pub struct Interval { /* private fields */ }
Periodic timer that ticks at a fixed interval.

Created via crate::context::interval. Call .tick().await to wait for the next tick.

Implementations

Source

impl Interval

pub async fn tick(&mut self)

Wait for the next tick.

pub fn reset(&mut self)

Reset the interval to fire one period from now.

pub fn reset_at(&mut self, deadline: Instant)

Reset the interval to fire at a specific instant.

pub fn period(&self) -> Duration

Get the interval period.

pub fn missed_tick_behavior(&self) -> MissedTickBehavior

Get the current missed tick behavior.

pub fn set_missed_tick_behavior(&mut self, behavior: MissedTickBehavior)

Set the missed tick behavior.