pub struct YieldNow(/* private fields */);Expand description
Future that yields once, then completes.
Returns Pending on first poll, wakes itself, completes on second poll.
Other ready tasks get a turn before this task resumes.